{% extends "page.html" %}

{% block stylesheets %}
  {{ super() }}

  <style>
    .voila-error {
      text-align: center;
    }
  </style>
{% endblock %}

{% block body %}
  <div class="voila-error">
    <h1>{{ status_code }}: {{ status_message }}</h1>

    {% block error_detail %}
    {% endblock %}
  </div>
{% endblock %}
