{% extends "voila/templates/base/error.html" %}

{% block stylesheets %}
  {{ super() }}

  <style>
    body {
      background-color: var(--jp-layout-color0);
      color: var(--jp-ui-font-color0);
    }
  </style>
{% endblock %}
